@@ -31,10 +31,10 @@ done
 rm -rf $DC_HELP_INSTALL_DIR/*
 
 # Copy English help files
-cp -r doc/en      $DC_HELP_INSTALL_DIR/
+cp -r doc/en   $DC_HELP_INSTALL_DIR/
 
 # Copy Russian help files
-cp -r doc/ru      $DC_HELP_INSTALL_DIR/
+cp -r doc/ru   $DC_HELP_INSTALL_DIR/
 
 # Copy Ukrainian help files
-cp -r doc/uk_UA   $DC_HELP_INSTALL_DIR/
\ No newline at end of file
+cp -r doc/uk   $DC_HELP_INSTALL_DIR/
\ No newline at end of file
